==> ejc-ai-impl-3.0.0-20250314.114159-47-sources.jar: com/ejianc/foundation/ai/vo/KnowledgeEmbeddingVO.java <==
package com.ejianc.foundation.ai.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识切片表（向量）
 * 
 * @author generator
 * 
 */
public class KnowledgeEmbeddingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long itemId; // 所属知识ID
    private String uuid; // 系统生成id
    private String content; // 知识内容
    private String initContent; // 自动生成的初始化的知识内容
    private String tableContent; // 知识内容,表格json形式存储
    private Integer sliceState; // 切片状态（1：启用，0：停用）
    private Integer type; // 类型，1自动生成，2自定义新增

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public String getTableContent() {
        return tableContent;
    }

    public void setTableContent(String tableContent) {
        this.tableContent = tableContent;
    }

    public Integer getSliceState() {
        return sliceState;
    }

    public void setSliceState(Integer sliceState) {
        this.sliceState = sliceState;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }
}

==> ejc-ai-impl-3.0.0-20250407.084013-67-sources.jar: com/ejianc/foundation/ai/vo/KnowledgeEmbeddingVO.java <==
package com.ejianc.foundation.ai.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识切片表（向量）
 * 
 * @author generator
 * 
 */
public class KnowledgeEmbeddingVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long itemId; // 所属知识ID
    private String uuid; // 系统生成id
    private String content; // 知识内容
    private String initContent; // 自动生成的初始化的知识内容
    private String tableContent; // 知识内容,表格json形式存储
    private Integer sliceState; // 切片状态（1：启用，0：停用）
    private Integer type; // 类型，1自动生成，2自定义新增
    private Integer sequence; // 排序号

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getInitContent() {
        return initContent;
    }

    public void setInitContent(String initContent) {
        this.initContent = initContent;
    }

    public String getTableContent() {
        return tableContent;
    }

    public void setTableContent(String tableContent) {
        this.tableContent = tableContent;
    }

    public Integer getSliceState() {
        return sliceState;
    }

    public void setSliceState(Integer sliceState) {
        this.sliceState = sliceState;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
}
